@@ -1,24 +1,5 @@
-/* Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 package org.xcsoar;
 
@@ -66,6 +47,8 @@ public class HM10Port
   private final Object gattStateSync = new Object();
   private int gattState = BluetoothGatt.STATE_DISCONNECTED;
 
+  private boolean setupCharacteristicsPending = false;
+
   public HM10Port(Context context, BluetoothDevice device)
     throws IOException
   {
@@ -99,6 +82,20 @@ public class HM10Port
       throw new Error("GATT device name characteristic not found");
   }
 
+  private void setupCharacteristics() throws Error {
+    findCharacteristics();
+
+    if (!gatt.setCharacteristicNotification(dataCharacteristic, true))
+      throw new Error("Could not enable GATT characteristic notification");
+
+    BluetoothGattDescriptor descriptor =
+      dataCharacteristic.getDescriptor(BluetoothUuids.CLIENT_CHARACTERISTIC_CONFIGURATION);
+    descriptor.setValue(BluetoothGattDescriptor.ENABLE_NOTIFICATION_VALUE);
+    gatt.writeDescriptor(descriptor);
+    portState = STATE_READY;
+    stateChanged();
+  }
+
   @Override
   public void onConnectionStateChange(BluetoothGatt gatt,
       int status,
@@ -121,7 +118,7 @@ public class HM10Port
       error(e.getMessage());
     }
 
-    writeBuffer.clear();
+    writeBuffer.reset();
     stateChanged();
     synchronized (gattStateSync) {
       gattState = newState;
@@ -136,19 +133,13 @@ public class HM10Port
       if (BluetoothGatt.GATT_SUCCESS != status)
         throw new Error("Discovering GATT services failed");
 
-      findCharacteristics();
-
-      if (!gatt.setCharacteristicNotification(dataCharacteristic, true))
-        throw new Error("Could not enable GATT characteristic notification");
-
-      BluetoothGattDescriptor descriptor =
-        dataCharacteristic.getDescriptor(BluetoothUuids.CLIENT_CHARACTERISTIC_CONFIGURATION);
-      descriptor.setValue(BluetoothGattDescriptor.ENABLE_NOTIFICATION_VALUE);
-      gatt.writeDescriptor(descriptor);
-      portState = STATE_READY;
+      /* request a high MTU (usually, HM-10 chips support 23 bytes);
+         postpone the setupCharacteristics() call until onMtuChanged()
+         is called - we can't do both at the same time */
+      setupCharacteristicsPending = true;
+      gatt.requestMtu(256);
     } catch (Error e) {
       error(e.getMessage());
-    } finally {
       stateChanged();
     }
   }
@@ -162,14 +153,11 @@ public class HM10Port
   @Override
   public void onCharacteristicWrite(BluetoothGatt gatt,
       BluetoothGattCharacteristic characteristic, int status) {
-    synchronized (writeBuffer) {
-      if (BluetoothGatt.GATT_SUCCESS == status) {
-        writeBuffer.beginWriteNextChunk(gatt, dataCharacteristic);
-        writeBuffer.notifyAll();
-      } else {
-        Log.e(TAG, "GATT characteristic write failed");
-        writeBuffer.setError();
-      }
+    if (BluetoothGatt.GATT_SUCCESS == status) {
+      writeBuffer.beginWriteNextChunk(gatt, dataCharacteristic);
+    } else {
+      Log.e(TAG, "GATT characteristic write failed");
+      writeBuffer.setError();
     }
   }
 
@@ -189,6 +177,25 @@ public class HM10Port
     }
   }
 
+  @Override
+  public void onMtuChanged(BluetoothGatt gatt, int mtu, int status) {
+    super.onMtuChanged(gatt, mtu, status);
+
+    if (status == BluetoothGatt.GATT_SUCCESS && mtu > 0)
+      writeBuffer.setMtu(mtu);
+
+    if (setupCharacteristicsPending) {
+      setupCharacteristicsPending = false;
+
+      try {
+        setupCharacteristics();
+      } catch (Error e) {
+        error(e.getMessage());
+        stateChanged();
+      }
+    }
+  }
+
   @Override public void setListener(PortListener _listener) {
     portListener = _listener;
   }
@@ -203,7 +210,7 @@ public class HM10Port
     safeDestruct.beginShutdown();
 
     shutdown = true;
-    writeBuffer.clear();
+    writeBuffer.reset();
     gatt.disconnect();
     synchronized (gattStateSync) {
       long waitUntil = System.currentTimeMillis() + DISCONNECT_TIMEOUT;
@@ -249,6 +256,12 @@ public class HM10Port
     if (0 == length)
       return 0;
 
+    if (portState != STATE_READY)
+      return 0;
+
+    assert(dataCharacteristic != null);
+    assert(deviceNameCharacteristic != null);
+
     return writeBuffer.write(gatt, dataCharacteristic,
                              deviceNameCharacteristic,
                              data, length);
