@@ -33,6 +33,7 @@ echo
 echo Installing dependencies for the Linux target...
 apt-get install ${APTOPTS[*]} make g++ \
   zlib1g-dev \
+  libfmt-dev \
   libsodium-dev \
   libfreetype6-dev \
   libpng-dev libjpeg-dev \
@@ -60,7 +61,7 @@ apt-get install ${APTOPTS[*]} dpkg-dev \
 echo
 
 echo Installing dependencies for compiling with LLVM / Clang...
-apt-get install ${APTOPTS[*]} llvm clang libc++-dev
+apt-get install ${APTOPTS[*]} llvm clang libc++-dev libc++abi-dev
 echo
 
 echo Installing dependencies for compiling targets which need libinput or GBM...
