@@ -1,31 +1,13 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2022 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #pragma once
 
 #include <cassert>
-#include <tchar.h>
 #include <cstdint>
+#include <functional>
+
+#include <tchar.h>
 
 static constexpr unsigned OUTBUFFERSIZE = 128;
 
@@ -56,8 +38,12 @@ public:
     DATE,
   };
 
+  using ModifiedCallback = std::function<void()>;
+
 private:
-  DataFieldListener *listener;
+  ModifiedCallback on_modified;
+
+  DataFieldListener *listener; // deprecated
 
   // all Types dataField support combolist except DataFieldString.
   const bool supports_combolist;
@@ -74,6 +60,11 @@ protected:
 public:
   virtual ~DataField() noexcept = default;
 
+  void SetOnModified(ModifiedCallback &&_callback) noexcept {
+    on_modified = std::move(_callback);
+  }
+
+  // deprecated
   void SetListener(DataFieldListener *_listener) noexcept {
     assert(listener == nullptr);
     assert(_listener != nullptr);
