@@ -11,20 +11,20 @@
 #include "util/Clamp.hpp"
 
 void
-OffsetHistory::Reset()
+OffsetHistory::Reset() noexcept
 {
   offsets.fill(PixelPoint{0, 0});
 }
 
 inline void
-OffsetHistory::Add(PixelPoint p)
+OffsetHistory::Add(PixelPoint p) noexcept
 {
   offsets[pos] = p;
   pos = (pos + 1) % offsets.size();
 }
 
 inline PixelPoint
-OffsetHistory::GetAverage() const
+OffsetHistory::GetAverage() const noexcept
 {
   int x = 0;
   int y = 0;
@@ -42,7 +42,7 @@ OffsetHistory::GetAverage() const
 }
 
 void
-GlueMapWindow::SetPan(bool enable)
+GlueMapWindow::SetPan(bool enable) noexcept
 {
   switch (follow_mode) {
   case FOLLOW_SELF:
@@ -64,7 +64,7 @@ GlueMapWindow::SetPan(bool enable)
 }
 
 void
-GlueMapWindow::TogglePan()
+GlueMapWindow::TogglePan() noexcept
 {
   switch (follow_mode) {
   case FOLLOW_SELF:
@@ -80,7 +80,7 @@ GlueMapWindow::TogglePan()
 }
 
 void
-GlueMapWindow::PanTo(const GeoPoint &location)
+GlueMapWindow::PanTo(const GeoPoint &location) noexcept
 {
   follow_mode = FOLLOW_PAN;
   SetLocation(location);
@@ -89,7 +89,7 @@ GlueMapWindow::PanTo(const GeoPoint &location)
 }
 
 void
-GlueMapWindow::UpdateScreenBounds()
+GlueMapWindow::UpdateScreenBounds() noexcept
 {
   visible_projection.UpdateScreenBounds();
 
@@ -107,7 +107,7 @@ GlueMapWindow::UpdateScreenBounds()
 }
 
 void
-GlueMapWindow::SetMapScale(double scale)
+GlueMapWindow::SetMapScale(double scale) noexcept
 {
   MapWindow::SetMapScale(scale);
   OnProjectionModified();
@@ -126,7 +126,7 @@ GlueMapWindow::SetMapScale(double scale)
 }
 
 void
-GlueMapWindow::RestoreMapScale()
+GlueMapWindow::RestoreMapScale() noexcept
 {
   const MapSettings &settings = CommonInterface::GetMapSettings();
   const bool circling =
@@ -139,7 +139,7 @@ GlueMapWindow::RestoreMapScale()
 }
 
 inline void
-GlueMapWindow::SaveDisplayModeScales()
+GlueMapWindow::SaveDisplayModeScales() noexcept
 {
   const MapSettings &settings = CommonInterface::GetMapSettings();
 
@@ -148,7 +148,7 @@ GlueMapWindow::SaveDisplayModeScales()
 }
 
 inline void
-GlueMapWindow::SwitchZoomClimb()
+GlueMapWindow::SwitchZoomClimb() noexcept
 {
   const MapSettings &settings = CommonInterface::GetMapSettings();
 
@@ -157,7 +157,7 @@ GlueMapWindow::SwitchZoomClimb()
 }
 
 void
-GlueMapWindow::UpdateDisplayMode()
+GlueMapWindow::UpdateDisplayMode() noexcept
 {
   /* not using MapWindowBlackboard here because these methods are
      called by the main thread */
@@ -176,7 +176,7 @@ GlueMapWindow::UpdateDisplayMode()
 }
 
 void
-GlueMapWindow::UpdateScreenAngle()
+GlueMapWindow::UpdateScreenAngle() noexcept
 {
   /* not using MapWindowBlackboard here because these methods are
      called by the main thread */
@@ -214,7 +214,7 @@ GlueMapWindow::UpdateScreenAngle()
 }
 
 void
-GlueMapWindow::UpdateMapScale()
+GlueMapWindow::UpdateMapScale() noexcept
 {
   /* not using MapWindowBlackboard here because these methods are
      called by the main thread */
@@ -256,14 +256,14 @@ GlueMapWindow::UpdateMapScale()
 }
 
 void
-GlueMapWindow::SetLocation(const GeoPoint location)
+GlueMapWindow::SetLocation(const GeoPoint location) noexcept
 {
   MapWindow::SetLocation(location);
   OnProjectionModified();
 }
 
 void
-GlueMapWindow::SetLocationLazy(const GeoPoint location)
+GlueMapWindow::SetLocationLazy(const GeoPoint location) noexcept
 {
   if (!visible_projection.IsValid()) {
     SetLocation(location);
@@ -279,7 +279,7 @@ GlueMapWindow::SetLocationLazy(const GeoPoint location)
 }
 
 void
-GlueMapWindow::UpdateProjection()
+GlueMapWindow::UpdateProjection() noexcept
 {
   const PixelRect rc = GetClientRect();
 
