@@ -26,7 +26,7 @@
 #include <stdio.h>
 
 void
-GlueMapWindow::DrawGesture(Canvas &canvas) const
+GlueMapWindow::DrawGesture(Canvas &canvas) const noexcept
 {
   if (!gestures.HasPoints())
     return;
@@ -47,7 +47,7 @@ GlueMapWindow::DrawGesture(Canvas &canvas) const
 }
 
 void
-GlueMapWindow::DrawCrossHairs(Canvas &canvas) const
+GlueMapWindow::DrawCrossHairs(Canvas &canvas) const noexcept
 {
   if (!render_projection.IsValid())
     return;
@@ -84,7 +84,7 @@ GlueMapWindow::DrawCrossHairs(Canvas &canvas) const
 }
 
 void
-GlueMapWindow::DrawPanInfo(Canvas &canvas) const
+GlueMapWindow::DrawPanInfo(Canvas &canvas) const noexcept
 {
   if (!render_projection.IsValid())
     return;
@@ -143,7 +143,7 @@ GlueMapWindow::DrawPanInfo(Canvas &canvas) const
 
 void
 GlueMapWindow::DrawGPSStatus(Canvas &canvas, const PixelRect &rc,
-                             const NMEAInfo &info) const
+                             const NMEAInfo &info) const noexcept
 {
   const TCHAR *txt;
   const MaskedIcon *icon;
@@ -174,7 +174,8 @@ GlueMapWindow::DrawGPSStatus(Canvas &canvas, const PixelRect &rc,
 }
 
 void
-GlueMapWindow::DrawFlightMode(Canvas &canvas, const PixelRect &rc) const
+GlueMapWindow::DrawFlightMode(Canvas &canvas,
+                              const PixelRect &rc) const noexcept
 {
   int offset = 0;
 
@@ -227,7 +228,8 @@ GlueMapWindow::DrawFlightMode(Canvas &canvas, const PixelRect &rc) const
 }
 
 void
-GlueMapWindow::DrawFinalGlide(Canvas &canvas, const PixelRect &rc) const
+GlueMapWindow::DrawFinalGlide(Canvas &canvas,
+                              const PixelRect &rc) const noexcept
 {
 
   if (GetMapSettings().final_glide_bar_display_mode==FinalGlideBarDisplayMode::OFF)
@@ -254,7 +256,7 @@ GlueMapWindow::DrawFinalGlide(Canvas &canvas, const PixelRect &rc) const
 }
 
 void
-GlueMapWindow::DrawVario(Canvas &canvas, const PixelRect &rc) const
+GlueMapWindow::DrawVario(Canvas &canvas, const PixelRect &rc) const noexcept
 {
   if (!GetMapSettings().vario_bar_enabled)
    return;
@@ -294,7 +296,7 @@ GlueMapWindow::SetBottomMarginFactor(unsigned margin_factor) noexcept
 
 void
 GlueMapWindow::DrawMapScale(Canvas &canvas, const PixelRect &rc,
-                            const MapWindowProjection &projection) const
+                            const MapWindowProjection &projection) const noexcept
 {
 
   PixelRect scale_pos(rc.left, rc.top, rc.right, rc.bottom - bottom_margin);
@@ -360,7 +362,7 @@ GlueMapWindow::DrawMapScale(Canvas &canvas, const PixelRect &rc,
 }
 
 void
-GlueMapWindow::DrawThermalEstimate(Canvas &canvas) const
+GlueMapWindow::DrawThermalEstimate(Canvas &canvas) const noexcept
 {
   if (InCirclingMode() && IsNearSelf()) {
     // in circling mode, draw thermal at actual estimated location
@@ -377,7 +379,8 @@ GlueMapWindow::DrawThermalEstimate(Canvas &canvas) const
 }
 
 void
-GlueMapWindow::RenderTrail(Canvas &canvas, const PixelPoint aircraft_pos)
+GlueMapWindow::RenderTrail(Canvas &canvas,
+                           const PixelPoint aircraft_pos) noexcept
 {
   TimeStamp min_time;
   switch(GetMapSettings().trail.length) {
@@ -400,13 +403,15 @@ GlueMapWindow::RenderTrail(Canvas &canvas, const PixelPoint aircraft_pos)
 }
 
 void
-GlueMapWindow::RenderTrackBearing(Canvas &canvas, const PixelPoint aircraft_pos)
+GlueMapWindow::RenderTrackBearing(Canvas &canvas,
+                                  const PixelPoint aircraft_pos) noexcept
 {
   DrawTrackBearing(canvas, aircraft_pos, InCirclingMode());
 }
 
 void
-GlueMapWindow::DrawThermalBand(Canvas &canvas, const PixelRect &rc) const
+GlueMapWindow::DrawThermalBand(Canvas &canvas,
+                               const PixelRect &rc) const noexcept
 {
   if (Calculated().task_stats.total.solution_remaining.IsOk() &&
       Calculated().task_stats.total.solution_remaining.altitude_difference > 50
@@ -442,7 +447,8 @@ GlueMapWindow::DrawThermalBand(Canvas &canvas, const PixelRect &rc) const
 }
 
 void
-GlueMapWindow::DrawStallRatio(Canvas &canvas, const PixelRect &rc) const
+GlueMapWindow::DrawStallRatio(Canvas &canvas,
+                              const PixelRect &rc) const noexcept
 {
   if (Basic().stall_ratio_available) {
     // JMW experimental, display stall sensor
