@@ -12,13 +12,72 @@
 #include "Tracking/SkyLines/Data.hpp"
 #include "util/StringCompare.hxx"
 
+#include <cassert>
+
+static void
+DrawFlarmTraffic(Canvas &canvas, const WindowProjection &projection,
+                 const TrafficLook &look, bool fading,
+                 const PixelPoint aircraft_pos,
+                 const FlarmTraffic &traffic) noexcept
+{
+  assert(traffic.location_available);
+
+  // Points for the screen coordinates for the icon, name and average climb
+  PixelPoint sc;
+
+  // If FLARM target not on the screen, move to the next one
+  if (auto p = projection.GeoToScreenIfVisible(traffic.location))
+    sc = *p;
+  else
+    return;
+
+  TextInBoxMode mode;
+  if (!fading)
+    mode.shape = LabelShape::OUTLINED;
+
+  // JMW TODO enhancement: decluttering of FLARM altitudes (sort by max lift)
+
+  // only draw labels if not close to aircraft
+  if ((sc - aircraft_pos).MagnitudeSquared() > Layout::Scale(30 * 30)) {
+    // If FLARM callsign/name available draw it to the canvas
+    if (traffic.HasName() && !StringIsEmpty(traffic.name)) {
+      // Draw the name 16 points below the icon
+      auto sc_name = sc;
+      sc_name.y -= Layout::Scale(20);
+
+      TextInBox(canvas, traffic.name, sc_name,
+                mode, projection.GetScreenRect());
+    }
+
+    if (!fading && traffic.climb_rate_avg30s >= 0.1) {
+      // If average climb data available draw it to the canvas
+      TCHAR label_avg[100];
+      FormatUserVerticalSpeed(traffic.climb_rate_avg30s,
+                              label_avg, false);
+
+      // Draw the average climb value above the icon
+      auto sc_av = sc;
+      sc_av.y += Layout::Scale(5);
+
+      TextInBox(canvas, label_avg, sc_av, mode,
+                projection.GetScreenRect());
+    }
+  }
+
+  auto color = FlarmFriends::GetFriendColor(traffic.id);
+
+  TrafficRenderer::Draw(canvas, look, fading, traffic,
+                        traffic.track - projection.GetScreenAngle(),
+                        color, sc);
+}
+
 /**
  * Draws the FLARM traffic icons onto the given canvas
  * @param canvas Canvas for drawing
  */
 void
 MapWindow::DrawFLARMTraffic(Canvas &canvas,
-                            const PixelPoint aircraft_pos) const
+                            const PixelPoint aircraft_pos) const noexcept
 {
   // Return if FLARM icons on moving map are disabled
   if (!GetMapSettings().show_flarm_on_map)
@@ -26,8 +85,6 @@ MapWindow::DrawFLARMTraffic(Canvas &canvas,
 
   // Return if FLARM data is not available
   const TrafficList &flarm = Basic().flarm.traffic;
-  if (flarm.IsEmpty())
-    return;
 
   const WindowProjection &projection = render_projection;
 
@@ -40,61 +97,21 @@ MapWindow::DrawFLARMTraffic(Canvas &canvas,
   canvas.Select(*traffic_look.font);
 
   // Circle through the FLARM targets
-  for (auto it = flarm.list.begin(), end = flarm.list.end();
-      it != end; ++it) {
-    const FlarmTraffic &traffic = *it;
-
+  for (const auto &traffic : flarm.list) {
     if (!traffic.location_available)
       continue;
 
-    // Save the location of the FLARM target
-    GeoPoint target_loc = traffic.location;
+    DrawFlarmTraffic(canvas, projection, traffic_look, false,
+                     aircraft_pos, traffic);
+  }
 
-    // Points for the screen coordinates for the icon, name and average climb
-    PixelPoint sc, sc_name, sc_av;
+  if (const auto &fading = GetFadingFlarmTraffic(); !fading.empty()) {
+    for (const auto &[id, traffic] : fading) {
+      assert(traffic.location_available);
 
-    // If FLARM target not on the screen, move to the next one
-    if (auto p = projection.GeoToScreenIfVisible(target_loc))
-      sc = *p;
-    else
-      continue;
-
-    // Draw the name 16 points below the icon
-    sc_name = sc;
-    sc_name.y -= Layout::Scale(20);
-
-    // Draw the average climb value above the icon
-    sc_av = sc;
-    sc_av.y += Layout::Scale(5);
-
-    TextInBoxMode mode;
-    mode.shape = LabelShape::OUTLINED;
-
-    // JMW TODO enhancement: decluttering of FLARM altitudes (sort by max lift)
-
-    int dx = sc_av.x - aircraft_pos.x;
-    int dy = sc_av.y - aircraft_pos.y;
-
-    // only draw labels if not close to aircraft
-    if (dx * dx + dy * dy > Layout::Scale(30 * 30)) {
-      // If FLARM callsign/name available draw it to the canvas
-      if (traffic.HasName() && !StringIsEmpty(traffic.name))
-        TextInBox(canvas, traffic.name, sc_name,
-                  mode, GetClientRect());
-
-      if (traffic.climb_rate_avg30s >= 0.1) {
-        // If average climb data available draw it to the canvas
-        TCHAR label_avg[100];
-        FormatUserVerticalSpeed(traffic.climb_rate_avg30s,
-                                       label_avg, false);
-        TextInBox(canvas, label_avg, sc_av, mode, GetClientRect());
-      }
+      DrawFlarmTraffic(canvas, projection, traffic_look, true,
+                       aircraft_pos, traffic);
     }
-
-    auto color = FlarmFriends::GetFriendColor(traffic.id);
-    TrafficRenderer::Draw(canvas, traffic_look, traffic,
-                          traffic.track - projection.GetScreenAngle(),
-                          color, sc);
   }
 }
 
@@ -104,8 +121,7 @@ MapWindow::DrawFLARMTraffic(Canvas &canvas,
  * @param canvas Canvas for drawing
  */
 void
-MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas,
-                            [[maybe_unused]] const PixelPoint aircraft_pos) const
+MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas) const noexcept
 {
 #ifdef ANDROID
 
@@ -126,41 +142,29 @@ MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas,
   // Circle through the GliderLink targets
   for (const auto &traf : traffic.list) {
 
-    // Save the location of the target
-    GeoPoint target_loc = traf.location;
-
     // Points for the screen coordinates for the icon, name and average climb
-    PixelPoint sc, sc_name, sc_av, sc_alt;
+    PixelPoint sc;
 
     // If FLARM target not on the screen, move to the next one
-    if (auto p = projection.GeoToScreenIfVisible(target_loc))
+    if (auto p = projection.GeoToScreenIfVisible(traf.location))
       sc = *p;
     else
       continue;
 
-    // Draw the callsign above the icon
-    sc_name = sc;
-    sc_name.x -= Layout::Scale(10);
-    sc_name.y -= Layout::Scale(15);
-
-    // Draw the average climb to the right of the icon
-    sc_av = sc;
-    sc_av.x += Layout::Scale(10);
-    sc_av.y -= Layout::Scale(8);
-
-    // Location of altitude label
-    sc_alt = sc;
-    sc_alt.x -= Layout::Scale(10);
-    sc_alt.y -= Layout::Scale(0);
-
     TextInBoxMode mode;
     mode.shape = LabelShape::OUTLINED;
     mode.align = TextInBoxMode::Alignment::RIGHT;
 
     // If callsign/name available draw it to the canvas
-    if (traf.HasName() && !StringIsEmpty(traf.name))
+    if (traf.HasName() && !StringIsEmpty(traf.name)) {
+      // Draw the callsign above the icon
+      auto sc_name = sc;
+      sc_name.x -= Layout::Scale(10);
+      sc_name.y -= Layout::Scale(15);
+
       TextInBox(canvas, traf.name, sc_name,
                 mode, GetClientRect());
+    }
 
     if (traf.climb_rate_received) {
 
@@ -169,6 +173,12 @@ MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas,
       FormatUserVerticalSpeed(traf.climb_rate,
                                      label_avg, false);
       mode.align = TextInBoxMode::Alignment::LEFT;
+
+      // Draw the average climb to the right of the icon
+      auto sc_av = sc;
+      sc_av.x += Layout::Scale(10);
+      sc_av.y -= Layout::Scale(8);
+
       TextInBox(canvas, label_avg, sc_av, mode, GetClientRect());
     }
 
@@ -180,6 +190,11 @@ MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas,
       double alt = (double(traf.altitude) - basic.gps_altitude) / 100.0;
       FormatRelativeUserAltitude(alt, label_alt, false);
 
+      // Location of altitude label
+      auto sc_alt = sc;
+      sc_alt.x -= Layout::Scale(10);
+      sc_alt.y -= Layout::Scale(0);
+
       mode.align = TextInBoxMode::Alignment::RIGHT;
       TextInBox(canvas, label_alt, sc_alt, mode, GetClientRect());
     }
@@ -195,7 +210,7 @@ MapWindow::DrawGLinkTraffic([[maybe_unused]] Canvas &canvas,
  * @param canvas Canvas for drawing
  */
 void
-MapWindow::DrawTeammate(Canvas &canvas) const
+MapWindow::DrawTeammate(Canvas &canvas) const noexcept
 {
   const TeamInfo &teamcode_info = Calculated();
 
@@ -208,7 +223,7 @@ MapWindow::DrawTeammate(Canvas &canvas) const
 #ifdef HAVE_SKYLINES_TRACKING
 
 void
-MapWindow::DrawSkyLinesTraffic(Canvas &canvas) const
+MapWindow::DrawSkyLinesTraffic(Canvas &canvas) const noexcept
 {
   if (DisplaySkyLinesTrafficMapMode::OFF == GetMapSettings().skylines_traffic_map_mode ||
       skylines_data == nullptr)
