@@ -67,8 +67,7 @@
  * @brief JasPer Memory Allocator
  */
 
-#ifndef JAS_MALLOC_H
-#define JAS_MALLOC_H
+#pragma once
 
 /******************************************************************************\
 * Includes.
@@ -128,5 +127,3 @@ JAS_DLLEXPORT size_t jas_get_mem_usage();
 #ifdef __cplusplus
 }
 #endif
-
-#endif
